@@ -393,7 +393,7 @@ def test_format_task_get(test_server, loop):
     server = yield from test_server(app)
     client = aiohttp.ClientSession(loop=loop)
     task = loop.create_task(client.get(server.make_url('/')))
-    assert "{}".format(task)[:18] == "<Task pending coro"
+    assert "{}".format(task).startswith("<Task pending")
     resp = yield from task
     resp.close()
     client.close()
@@ -547,10 +547,12 @@ def test_raw_headers(loop, test_client):
     client = yield from test_client(app)
     resp = yield from client.get('/')
     assert resp.status == 200
-    assert resp.raw_headers == ((b'Content-Length', b'0'),
-                                (b'Content-Type', b'application/octet-stream'),
-                                (b'Date', mock.ANY),
-                                (b'Server', mock.ANY))
+
+    raw_headers = tuple((bytes(h), bytes(v)) for h, v in resp.raw_headers)
+    assert raw_headers == ((b'Content-Length', b'0'),
+                           (b'Content-Type', b'application/octet-stream'),
+                           (b'Date', mock.ANY),
+                           (b'Server', mock.ANY))
     resp.close()
 
 
@@ -635,11 +637,12 @@ def test_timeout_on_session_read_timeout(loop, test_client, mocker):
     client = yield from test_client(app, connector=conn, read_timeout=0.01)
 
     with pytest.raises(asyncio.TimeoutError):
-        yield from client.get('/', timeout=None)
+        yield from client.get('/')
 
 
 @asyncio.coroutine
-def test_timeout_on_reading_data(loop, test_client):
+def test_timeout_on_reading_data(loop, test_client, mocker):
+    mocker.patch('aiohttp.helpers.ceil').side_effect = ceil
 
     @asyncio.coroutine
     def handler(request):
@@ -661,6 +664,8 @@ def test_timeout_on_reading_data(loop, test_client):
 
 @asyncio.coroutine
 def test_timeout_none(loop, test_client, mocker):
+    mocker.patch('aiohttp.helpers.ceil').side_effect = ceil
+
     @asyncio.coroutine
     def handler(request):
         resp = web.StreamResponse()
@@ -1101,8 +1106,6 @@ def test_POST_DATA_formdats_with_charset(loop, test_client):
     def handler(request):
         mp = yield from request.post()
         assert 'name' in mp
-        from pprint import pprint
-        pprint(dict(request.headers))
         return web.Response(text=mp['name'])
 
     app = web.Application()
