@@ -8,7 +8,7 @@ import zlib
 from unittest import mock
 
 import pytest
-from multidict import CIMultiDict, CIMultiDictProxy, upstr
+from multidict import CIMultiDict, CIMultiDictProxy, istr
 from yarl import URL
 
 import aiohttp
@@ -96,11 +96,22 @@ def test_version_default(make_request):
     assert req.version == (1, 1)
 
 
+def test_request_info(make_request):
+    req = make_request('get', 'http://python.org/')
+    assert req.request_info == (URL('http://python.org/'), 'GET', req.headers)
+
+
 def test_version_err(make_request):
     with pytest.raises(ValueError):
         make_request('get', 'http://python.org/', version='1.c')
 
 
+def test_https_proxy(make_request):
+    with pytest.raises(ValueError):
+        make_request(
+            'get', 'http://python.org/', proxy=URL('https://proxy.org'))
+
+
 def test_keep_alive(make_request):
     req = make_request('get', 'http://python.org/', version=(0, 9))
     assert not req.keep_alive()
@@ -246,7 +257,7 @@ def test_default_headers_useragent_custom(make_request):
 
 def test_skip_default_useragent_header(make_request):
     req = make_request('get', 'http://python.org/',
-                       skip_auto_headers=set([upstr('user-agent')]))
+                       skip_auto_headers=set([istr('user-agent')]))
 
     assert 'User-Agent' not in req.headers
 
@@ -855,7 +866,7 @@ def test_data_stream(loop, buf, conn):
     assert req.headers['TRANSFER-ENCODING'] == 'chunked'
 
     resp = req.send(conn)
-    assert isinstance(req._writer, asyncio.Future)
+    assert helpers.isfuture(req._writer)
     yield from resp.wait_for_close()
     assert req._writer is None
 
@@ -875,7 +886,7 @@ def test_data_file(loop, buf, conn):
     assert req.headers['TRANSFER-ENCODING'] == 'chunked'
 
     resp = req.send(conn)
-    assert isinstance(req._writer, asyncio.Future)
+    assert helpers.isfuture(req._writer)
     yield from resp.wait_for_close()
     assert req._writer is None
     assert buf.split(b'\r\n\r\n', 1)[1] == \
@@ -1020,6 +1031,21 @@ def test_custom_response_class(loop, conn):
     resp.close()
 
 
+@asyncio.coroutine
+def test_oserror_on_write_bytes(loop, conn):
+    req = ClientRequest(
+        'POST', URL('http://python.org/'), loop=loop)
+
+    writer = mock.Mock()
+    writer.write.side_effect = OSError
+
+    yield from req.write_bytes(writer, conn)
+
+    assert conn.protocol.set_exception.called
+    exc = conn.protocol.set_exception.call_args[0][0]
+    assert isinstance(exc, aiohttp.ClientOSError)
+
+
 @asyncio.coroutine
 def test_terminate(loop, conn):
     req = ClientRequest('get', URL('http://python.org'), loop=loop)
