@@ -17,7 +17,7 @@ from yarl import URL
 import aiohttp
 from aiohttp import client, helpers, web
 from aiohttp.client import ClientRequest
-from aiohttp.connector import Connection
+from aiohttp.connector import Connection, _DNSCacheTable
 from aiohttp.test_utils import unused_port
 
 
@@ -225,8 +225,6 @@ def test_release_acquired_closed(loop, key):
 
 
 def test_release(loop, key):
-    loop.time = mock.Mock(return_value=10)
-
     conn = aiohttp.BaseConnector(loop=loop)
     conn._release_waiter = mock.Mock()
 
@@ -237,14 +235,13 @@ def test_release(loop, key):
 
     conn._release(key, proto)
     assert conn._release_waiter.called
-    assert conn._conns[key][0] == (proto, 10)
+    assert conn._conns[key][0][0] == proto
+    assert conn._conns[key][0][1] == pytest.approx(loop.time(), abs=0.1)
     assert not conn._cleanup_closed_transports
     conn.close()
 
 
 def test_release_ssl_transport(loop, ssl_key):
-    loop.time = mock.Mock(return_value=10)
-
     conn = aiohttp.BaseConnector(loop=loop, enable_cleanup_closed=True)
     conn._release_waiter = mock.Mock()
 
@@ -345,7 +342,7 @@ def test_release_close(loop):
 
 
 @asyncio.coroutine
-def test_tcp_connector_resolve_host_use_dns_cache(loop):
+def test_tcp_connector_resolve_host(loop):
     conn = aiohttp.TCPConnector(loop=loop, use_dns_cache=True)
 
     res = yield from conn._resolve_host('localhost', 8080)
@@ -365,13 +362,57 @@ def test_tcp_connector_resolve_host_use_dns_cache(loop):
 
 
 @asyncio.coroutine
-def test_tcp_connector_resolve_host_twice_use_dns_cache(loop):
-    conn = aiohttp.TCPConnector(loop=loop, use_dns_cache=True)
+def dns_response():
+    return ["127.0.0.1"]
 
-    res = yield from conn._resolve_host('localhost', 8080)
-    res2 = yield from conn._resolve_host('localhost', 8080)
 
-    assert res is res2
+@asyncio.coroutine
+def test_tcp_connector_dns_cache_not_expired(loop):
+    with mock.patch('aiohttp.connector.DefaultResolver') as m_resolver:
+        conn = aiohttp.TCPConnector(
+            loop=loop,
+            use_dns_cache=True,
+            ttl_dns_cache=10
+        )
+        m_resolver().resolve.return_value = dns_response()
+        yield from conn._resolve_host('localhost', 8080)
+        yield from conn._resolve_host('localhost', 8080)
+        m_resolver().resolve.assert_called_once_with(
+            'localhost',
+            8080,
+            family=0
+        )
+
+
+@asyncio.coroutine
+def test_tcp_connector_dns_cache_forever(loop):
+    with mock.patch('aiohttp.connector.DefaultResolver') as m_resolver:
+        conn = aiohttp.TCPConnector(
+            loop=loop,
+            use_dns_cache=True,
+            ttl_dns_cache=10
+        )
+        m_resolver().resolve.return_value = dns_response()
+        yield from conn._resolve_host('localhost', 8080)
+        yield from conn._resolve_host('localhost', 8080)
+        m_resolver().resolve.assert_called_once_with(
+            'localhost',
+            8080,
+            family=0
+        )
+
+
+@asyncio.coroutine
+def test_tcp_connector_use_dns_cache_disabled(loop):
+    with mock.patch('aiohttp.connector.DefaultResolver') as m_resolver:
+        conn = aiohttp.TCPConnector(loop=loop, use_dns_cache=False)
+        m_resolver().resolve.return_value = dns_response()
+        yield from conn._resolve_host('localhost', 8080)
+        yield from conn._resolve_host('localhost', 8080)
+        m_resolver().resolve.assert_has_calls([
+            mock.call('localhost', 8080, family=0),
+            mock.call('localhost', 8080, family=0)
+        ])
 
 
 def test_get_pop_empty_conns(loop):
@@ -412,13 +453,15 @@ def test_release_close_do_not_delete_existing_connections(loop):
 
 
 def test_release_not_started(loop):
-    loop.time = mock.Mock(return_value=10)
     conn = aiohttp.BaseConnector(loop=loop)
     proto = mock.Mock(should_close=False)
     key = 1
     conn._acquired.add(proto)
     conn._release(key, proto)
-    assert conn._conns == {1: [(proto, 10)]}
+    # assert conn._conns == {1: [(proto, 10)]}
+    rec = conn._conns[1]
+    assert rec[0][0] == proto
+    assert rec[0][1] == pytest.approx(loop.time(), abs=0.01)
     assert not proto.close.called
     conn.close()
 
@@ -556,6 +599,9 @@ def test_cleanup3():
 
 
 def test_cleanup_closed(loop, mocker):
+    if not hasattr(loop, '__dict__'):
+        pytest.skip("can not override loop attributes")
+
     mocker.spy(loop, 'call_at')
     conn = aiohttp.BaseConnector(loop=loop, enable_cleanup_closed=True)
 
@@ -604,13 +650,13 @@ def test_tcp_connector_fingerprint_invalid(loop):
 
 def test_tcp_connector_clear_dns_cache(loop):
     conn = aiohttp.TCPConnector(loop=loop)
-    info = object()
-    conn._cached_hosts[('localhost', 123)] = info
-    conn._cached_hosts[('localhost', 124)] = info
+    hosts = ['a', 'b']
+    conn._cached_hosts.add(('localhost', 123), hosts)
+    conn._cached_hosts.add(('localhost', 124), hosts)
     conn.clear_dns_cache('localhost', 123)
-    assert conn.cached_hosts == {('localhost', 124): info}
+    assert ('localhost', 123) not in conn.cached_hosts
     conn.clear_dns_cache('localhost', 123)
-    assert conn.cached_hosts == {('localhost', 124): info}
+    assert ('localhost', 123) not in conn.cached_hosts
     conn.clear_dns_cache()
     assert conn.cached_hosts == {}
 
@@ -993,7 +1039,7 @@ def test_limit_property(loop):
     conn.close()
 
 
-def test_limit_by_host_property(loop):
+def test_limit_per_host_property(loop):
     conn = aiohttp.BaseConnector(loop=loop, limit_per_host=15)
     assert 15 == conn.limit_per_host
 
@@ -1149,3 +1195,58 @@ class TestHttpClientConnector(unittest.TestCase):
             self.loop.run_until_complete(connector.connect(req))
 
         resolver.resolve.assert_not_called()
+
+
+class TestDNSCacheTable:
+
+    @pytest.fixture
+    def dns_cache_table(self):
+        return _DNSCacheTable()
+
+    def test_addrs(self, dns_cache_table):
+        dns_cache_table.add('localhost', ['127.0.0.1'])
+        dns_cache_table.add('foo', ['127.0.0.2'])
+        assert dns_cache_table.addrs == {
+            'localhost': ['127.0.0.1'],
+            'foo': ['127.0.0.2']
+        }
+
+    def test_remove(self, dns_cache_table):
+        dns_cache_table.add('localhost', ['127.0.0.1'])
+        dns_cache_table.remove('localhost')
+        assert dns_cache_table.addrs == {}
+
+    def test_clear(self, dns_cache_table):
+        dns_cache_table.add('localhost', ['127.0.0.1'])
+        dns_cache_table.clear()
+        assert dns_cache_table.addrs == {}
+
+    def test_not_expired_ttl_None(self, dns_cache_table):
+        dns_cache_table.add('localhost', ['127.0.0.1'])
+        assert not dns_cache_table.expired('localhost')
+
+    def test_not_expired_ttl(self):
+        dns_cache_table = _DNSCacheTable(ttl=0.1)
+        dns_cache_table.add('localhost', ['127.0.0.1'])
+        assert not dns_cache_table.expired('localhost')
+
+    @asyncio.coroutine
+    def test_expired_ttl(self, loop):
+        dns_cache_table = _DNSCacheTable(ttl=0.01)
+        dns_cache_table.add('localhost', ['127.0.0.1'])
+        yield from asyncio.sleep(0.01, loop=loop)
+        assert dns_cache_table.expired('localhost')
+
+    def test_next_addrs(self, dns_cache_table):
+        dns_cache_table.add('foo', ['127.0.0.1', '127.0.0.2'])
+
+        # max elements returned are the full list of addrs
+        addrs = list(dns_cache_table.next_addrs('foo'))
+        assert addrs == ['127.0.0.1', '127.0.0.2']
+
+        # different calls to next_addrs return the hosts using
+        # a round robin strategy.
+        addrs = dns_cache_table.next_addrs('foo')
+        assert next(addrs) == '127.0.0.1'
+        addrs = dns_cache_table.next_addrs('foo')
+        assert next(addrs) == '127.0.0.2'
