@@ -5,6 +5,7 @@ import sys
 from unittest import mock
 
 import pytest
+from yarl import URL
 
 from aiohttp import helpers
 
@@ -119,7 +120,7 @@ def test_access_logger_atoms(mocker):
     utcnow = datetime.datetime(1843, 1, 1, 0, 0)
     mock_datetime.datetime.utcnow.return_value = utcnow
     mock_getpid.return_value = 42
-    log_format = '%a %t %P %l %u %r %s %b %O %T %Tf %D'
+    log_format = '%a %t %P %l %u %r %s %b %T %Tf %D'
     mock_logger = mock.Mock()
     access_logger = helpers.AccessLogger(mock_logger, log_format)
     message = mock.Mock(headers={}, method="GET", path="/path", version=(1, 1))
@@ -130,9 +131,8 @@ def test_access_logger_atoms(mocker):
     access_logger.log(message, environ, response, transport, 3.1415926)
     assert not mock_logger.exception.called
     expected = ('127.0.0.2 [01/Jan/1843:00:00:00 +0000] <42> - - '
-                'GET /path HTTP/1.1 200 42 42 3 3.141593 3141593')
+                'GET /path HTTP/1.1 200 42 3 3.141593 3141593')
     extra = {
-        'bytes_sent': 42,
         'first_request_line': 'GET /path HTTP/1.1',
         'process_id': '<42>',
         'remote_address': '127.0.0.2',
@@ -256,7 +256,7 @@ class TestReify:
             a.prop = 123
 
 
-@pytest.mark.skipif(sys.version_info < (3, 5), reason='old python')
+@pytest.mark.skipif(sys.version_info < (3, 5, 2), reason='old python')
 def test_create_future_with_new_loop():
     # We should use the new create_future() if it's available.
     mock_loop = mock.Mock()
@@ -393,14 +393,13 @@ class TestTimeService:
         assert time_service.strtime() == 'Sun, 30 Oct 2016 03:13:52 GMT'
 
     def test_recalc_time(self, time_service, mocker):
-        mocker.spy(time_service._loop, 'time')
-
-        time_service._time = 123
+        time = time_service._loop.time()
+        time_service._time = time
         time_service._strtime = 'asd'
         time_service._count = 1000000
         time_service._on_cb()
         assert time_service._strtime is None
-        assert time_service._time > 1234
+        assert time_service._time > time
         assert time_service._count == 0
 
 
@@ -425,6 +424,26 @@ def test_timeout_handle_cb_exc(loop):
     assert not handle._callbacks
 
 
+def test_timer_context_cancelled():
+    with mock.patch('aiohttp.helpers.asyncio') as m_asyncio:
+        m_asyncio.TimeoutError = asyncio.TimeoutError
+        loop = mock.Mock()
+        ctx = helpers.TimerContext(loop)
+        ctx.timeout()
+
+        with pytest.raises(asyncio.TimeoutError):
+            with ctx:
+                pass
+
+        assert m_asyncio.Task.current_task.return_value.cancel.called
+
+
+def test_timer_context_no_task(loop):
+    with pytest.raises(RuntimeError):
+        with helpers.TimerContext(loop):
+            pass
+
+
 # ----------------------------------- FrozenList ----------------------
 
 
@@ -480,6 +499,12 @@ def test_ceil_timeout(loop):
         assert timeout._cancel_handler is None
 
 
+def test_ceil_timeout_no_task(loop):
+    with pytest.raises(RuntimeError):
+        with helpers.CeilTimeout(10, loop=loop):
+            pass
+
+
 # -------------------------------- ContentDisposition -------------------
 
 def test_content_disposition():
@@ -508,3 +533,15 @@ def test_set_content_disposition_bad_param():
     with pytest.raises(ValueError):
         helpers.content_disposition_header('inline',
                                            **{'foo\x00bar': 'baz'})
+
+
+def test_dummy_cookie_jar(loop):
+    cookie = helpers.SimpleCookie('foo=bar; Domain=example.com;')
+    dummy_jar = helpers.DummyCookieJar(loop=loop)
+    assert len(dummy_jar) == 0
+    dummy_jar.update_cookies(cookie)
+    assert len(dummy_jar) == 0
+    with pytest.raises(StopIteration):
+        next(iter(dummy_jar))
+    assert dummy_jar.filter_cookies(URL("http://example.com/")) is None
+    dummy_jar.clear()
