@@ -1,8 +1,8 @@
+import asyncio
 import contextlib
 import os
 import socket
 import ssl
-
 from io import StringIO
 from unittest import mock
 from uuid import uuid4
@@ -40,7 +40,15 @@ skip_if_no_unix_socks = pytest.mark.skipif(
 del _has_unix_domain_socks, _abstract_path_failed
 
 
+# tokio event loop does not allow to override attributes
+def skip_if_no_dict(loop):
+    if not hasattr(loop, '__dict__'):
+        pytest.skip("can not override loop attributes")
+
+
 def test_run_app_http(loop, mocker):
+    skip_if_no_dict(loop)
+
     mocker.spy(loop, 'create_server')
     loop.call_later(0.05, loop.stop)
 
@@ -49,10 +57,30 @@ def test_run_app_http(loop, mocker):
 
     web.run_app(app, loop=loop, print=lambda *args: None)
 
+    assert not loop.is_closed()
+    loop.create_server.assert_called_with(mock.ANY, '0.0.0.0', 8080,
+                                          ssl=None, backlog=128)
+    app.startup.assert_called_once_with()
+
+
+def test_run_app_close_loop(loop, mocker):
+    skip_if_no_dict(loop)
+
+    mocker.spy(loop, 'create_server')
+    loop.call_later(0.05, loop.stop)
+
+    asyncio.set_event_loop(loop)
+
+    app = web.Application()
+    mocker.spy(app, 'startup')
+
+    web.run_app(app, print=lambda *args: None)
+
     assert loop.is_closed()
     loop.create_server.assert_called_with(mock.ANY, '0.0.0.0', 8080,
                                           ssl=None, backlog=128)
     app.startup.assert_called_once_with()
+    asyncio.set_event_loop(None)
 
 
 mock_unix_server_single = [
@@ -181,6 +209,8 @@ def test_run_app_mixed_bindings(mocker, run_app_kwargs, expected_server_calls,
 
 
 def test_run_app_http_access_format(loop, mocker):
+    skip_if_no_dict(loop)
+
     mocker.spy(loop, 'create_server')
     loop.call_later(0.05, loop.stop)
 
@@ -190,7 +220,7 @@ def test_run_app_http_access_format(loop, mocker):
     web.run_app(app, loop=loop,
                 print=lambda *args: None, access_log_format='%a')
 
-    assert loop.is_closed()
+    assert not loop.is_closed()
     cs = loop.create_server
     cs.assert_called_with(mock.ANY, '0.0.0.0', 8080, ssl=None, backlog=128)
     assert cs.call_args[0][0]._kwargs['access_log_format'] == '%a'
@@ -198,6 +228,8 @@ def test_run_app_http_access_format(loop, mocker):
 
 
 def test_run_app_https(loop, mocker):
+    skip_if_no_dict(loop)
+
     mocker.spy(loop, 'create_server')
     loop.call_later(0.05, loop.stop)
 
@@ -209,13 +241,15 @@ def test_run_app_https(loop, mocker):
     web.run_app(app, loop=loop,
                 ssl_context=ssl_context, print=lambda *args: None)
 
-    assert loop.is_closed()
+    assert not loop.is_closed()
     loop.create_server.assert_called_with(mock.ANY, '0.0.0.0', 8443,
                                           ssl=ssl_context, backlog=128)
     app.startup.assert_called_once_with()
 
 
 def test_run_app_nondefault_host_port(loop, unused_port, mocker):
+    skip_if_no_dict(loop)
+
     port = unused_port()
     host = 'localhost'
 
@@ -228,13 +262,15 @@ def test_run_app_nondefault_host_port(loop, unused_port, mocker):
     web.run_app(app, loop=loop,
                 host=host, port=port, print=lambda *args: None)
 
-    assert loop.is_closed()
+    assert not loop.is_closed()
     loop.create_server.assert_called_with(mock.ANY, host, port,
                                           ssl=None, backlog=128)
     app.startup.assert_called_once_with()
 
 
 def test_run_app_custom_backlog(loop, mocker):
+    skip_if_no_dict(loop)
+
     mocker.spy(loop, 'create_server')
     loop.call_later(0.05, loop.stop)
 
@@ -243,7 +279,7 @@ def test_run_app_custom_backlog(loop, mocker):
 
     web.run_app(app, loop=loop, backlog=10, print=lambda *args: None)
 
-    assert loop.is_closed()
+    assert not loop.is_closed()
     loop.create_server.assert_called_with(mock.ANY, '0.0.0.0', 8080,
                                           ssl=None, backlog=10)
     app.startup.assert_called_once_with()
@@ -251,6 +287,8 @@ def test_run_app_custom_backlog(loop, mocker):
 
 @skip_if_no_unix_socks
 def test_run_app_http_unix_socket(loop, mocker, shorttmpdir):
+    skip_if_no_dict(loop)
+
     mocker.spy(loop, 'create_unix_server')
     loop.call_later(0.05, loop.stop)
 
@@ -261,7 +299,7 @@ def test_run_app_http_unix_socket(loop, mocker, shorttmpdir):
     printed = StringIO()
     web.run_app(app, loop=loop, path=sock_path, print=printed.write)
 
-    assert loop.is_closed()
+    assert not loop.is_closed()
     loop.create_unix_server.assert_called_with(mock.ANY, sock_path,
                                                ssl=None, backlog=128)
     app.startup.assert_called_once_with()
@@ -270,6 +308,8 @@ def test_run_app_http_unix_socket(loop, mocker, shorttmpdir):
 
 @skip_if_no_unix_socks
 def test_run_app_https_unix_socket(loop, mocker, shorttmpdir):
+    skip_if_no_dict(loop)
+
     mocker.spy(loop, 'create_unix_server')
     loop.call_later(0.05, loop.stop)
 
@@ -282,7 +322,7 @@ def test_run_app_https_unix_socket(loop, mocker, shorttmpdir):
     web.run_app(app, loop=loop, path=sock_path, ssl_context=ssl_context,
                 print=printed.write)
 
-    assert loop.is_closed()
+    assert not loop.is_closed()
     loop.create_unix_server.assert_called_with(mock.ANY, sock_path,
                                                ssl=ssl_context, backlog=128)
     app.startup.assert_called_once_with()
@@ -294,6 +334,8 @@ def test_run_app_stale_unix_socket(loop, mocker, shorttmpdir):
     """Older asyncio event loop implementations are known to halt server
     creation when a socket path from a previous server bind still exists.
     """
+    skip_if_no_dict(loop)
+
     loop.call_later(0.05, loop.stop)
 
     app = web.Application()
@@ -303,7 +345,7 @@ def test_run_app_stale_unix_socket(loop, mocker, shorttmpdir):
 
     web.run_app(app, loop=loop,
                 path=sock_path_string, print=lambda *args: None)
-    assert loop.is_closed()
+    assert not loop.is_closed()
 
     if sock_path.check():
         # New app run using same socket path
@@ -341,7 +383,6 @@ def test_run_app_abstract_linux_socket(loop, mocker):
     web.run_app(
         app, path=sock_path.decode('ascii', 'ignore'), loop=loop,
         print=lambda *args: None)
-    assert loop.is_closed()
 
     # New app run using same socket path
     with loop_context() as loop:
@@ -386,6 +427,8 @@ def test_run_app_existing_file_conflict(loop, mocker, shorttmpdir):
 
 
 def test_run_app_preexisting_inet_socket(loop, mocker):
+    skip_if_no_dict(loop)
+
     mocker.spy(loop, 'create_server')
     loop.call_later(0.05, loop.stop)
 
@@ -400,7 +443,7 @@ def test_run_app_preexisting_inet_socket(loop, mocker):
         printed = StringIO()
         web.run_app(app, loop=loop, sock=sock, print=printed.write)
 
-        assert loop.is_closed()
+        assert not loop.is_closed()
         loop.create_server.assert_called_with(
             mock.ANY, sock=sock, backlog=128, ssl=None
         )
@@ -410,6 +453,8 @@ def test_run_app_preexisting_inet_socket(loop, mocker):
 
 @skip_if_no_unix_socks
 def test_run_app_preexisting_unix_socket(loop, mocker):
+    skip_if_no_dict(loop)
+
     mocker.spy(loop, 'create_server')
     loop.call_later(0.05, loop.stop)
 
@@ -425,7 +470,7 @@ def test_run_app_preexisting_unix_socket(loop, mocker):
         printed = StringIO()
         web.run_app(app, loop=loop, sock=sock, print=printed.write)
 
-        assert loop.is_closed()
+        assert not loop.is_closed()
         loop.create_server.assert_called_with(
             mock.ANY, sock=sock, backlog=128, ssl=None
         )
@@ -434,6 +479,8 @@ def test_run_app_preexisting_unix_socket(loop, mocker):
 
 
 def test_run_app_multiple_preexisting_sockets(loop, mocker):
+    skip_if_no_dict(loop)
+
     mocker.spy(loop, 'create_server')
     loop.call_later(0.05, loop.stop)
 
@@ -451,7 +498,6 @@ def test_run_app_multiple_preexisting_sockets(loop, mocker):
         printed = StringIO()
         web.run_app(app, loop=loop, sock=(sock1, sock2), print=printed.write)
 
-        assert loop.is_closed()
         loop.create_server.assert_has_calls([
             mock.call(mock.ANY, sock=sock1, backlog=128, ssl=None),
             mock.call(mock.ANY, sock=sock2, backlog=128, ssl=None)
