@@ -67,6 +67,16 @@ def test_app_make_handler_debug_exc(loop, mocker, debug):
                            debug=debug)
 
 
+def test_app_make_handler_args(loop, mocker):
+    app = web.Application(handler_args={'test': True})
+    srv = mocker.patch('aiohttp.web.Server')
+
+    app.make_handler(loop=loop)
+    srv.assert_called_with(app._handle,
+                           request_factory=app._make_request,
+                           loop=loop, debug=mock.ANY, test=True)
+
+
 @asyncio.coroutine
 def test_app_register_on_finish():
     app = web.Application()
@@ -179,14 +189,41 @@ def test_app_delitem():
     assert len(app) == 0
 
 
+def test_app_freeze():
+    app = web.Application()
+    subapp = mock.Mock()
+    app._subapps.append(subapp)
+
+    app.freeze()
+    assert subapp.freeze.called
+
+    app.freeze()
+    assert len(subapp.freeze.call_args_list) == 1
+
+
 def test_secure_proxy_ssl_header_default():
     app = web.Application()
     assert app._secure_proxy_ssl_header is None
 
 
-@asyncio.coroutine
 def test_secure_proxy_ssl_header_non_default(loop):
     app = web.Application()
     hdr = ('X-Forwarded-Proto', 'https')
     app.make_handler(secure_proxy_ssl_header=hdr, loop=loop)
     assert app._secure_proxy_ssl_header is hdr
+
+
+def test_secure_proxy_ssl_header_init(loop):
+    hdr = ('X-Forwarded-Proto', 'https')
+    app = web.Application(secure_proxy_ssl_header=hdr)
+    assert app._secure_proxy_ssl_header is hdr
+    app.make_handler(loop=loop)
+    assert app._secure_proxy_ssl_header is hdr
+
+
+def test_equality():
+    app1 = web.Application()
+    app2 = web.Application()
+
+    assert app1 == app1
+    assert app1 != app2
