@@ -2,25 +2,26 @@ import asyncio
 from unittest import mock
 
 from aiohttp import web
-from aiohttp.test_utils import make_mocked_coro
+from aiohttp.test_utils import make_mocked_coro, make_mocked_request
 
 
 def test_repr(loop):
-    app = web.Application(loop=loop)
-    manager = app.make_handler()
+    app = web.Application()
+    manager = app.make_handler(loop=loop)
     handler = manager()
 
     assert '<RequestHandler none:none disconnected>' == repr(handler)
 
     handler.transport = object()
-    handler._meth = 'GET'
-    handler._path = '/index.html'
-    assert '<RequestHandler GET:/index.html connected>' == repr(handler)
+    request = make_mocked_request('GET', '/index.html')
+    handler._request = request
+    # assert '<RequestHandler GET:/index.html connected>' == repr(handler)
+    assert '<RequestHandler none:none connected>' == repr(handler)
 
 
 def test_connections(loop):
-    app = web.Application(loop=loop)
-    manager = app.make_handler()
+    app = web.Application()
+    manager = app.make_handler(loop=loop)
     assert manager.connections == []
 
     handler = object()
@@ -34,8 +35,8 @@ def test_connections(loop):
 
 @asyncio.coroutine
 def test_finish_connection_no_timeout(loop):
-    app = web.Application(loop=loop)
-    manager = app.make_handler()
+    app = web.Application()
+    manager = app.make_handler(loop=loop)
 
     handler = mock.Mock()
     handler.shutdown = make_mocked_coro(mock.Mock())
@@ -51,8 +52,8 @@ def test_finish_connection_no_timeout(loop):
 
 @asyncio.coroutine
 def test_finish_connection_timeout(loop):
-    app = web.Application(loop=loop)
-    manager = app.make_handler()
+    app = web.Application()
+    manager = app.make_handler(loop=loop)
 
     handler = mock.Mock()
     handler.shutdown = make_mocked_coro(mock.Mock())
@@ -64,9 +65,3 @@ def test_finish_connection_timeout(loop):
     manager.connection_lost(handler, None)
     assert manager.connections == []
     handler.shutdown.assert_called_with(0.1)
-
-
-def test_secure_proxy_ssl_header_default(loop):
-    app = web.Application(loop=loop)
-    manager = app.make_handler()
-    assert manager.secure_proxy_ssl_header is None
