@@ -67,6 +67,12 @@ def test_stream_response_ctor():
     assert 200 == resp.status
     assert resp.keep_alive is None
 
+    assert resp.task is None
+
+    req = mock.Mock()
+    resp._req = req
+    assert resp.task is req.task
+
 
 def test_content_length():
     resp = StreamResponse()
@@ -827,6 +833,12 @@ def test_assign_nonstr_text():
     assert 4 == resp.content_length
 
 
+def test_response_set_content_length():
+    resp = Response()
+    with pytest.raises(RuntimeError):
+        resp.content_length = 1
+
+
 @asyncio.coroutine
 def test_send_headers_for_empty_body(buf, writer):
     req = make_request('GET', '/', payload_writer=writer)
